==> chatroom-2.4.1-sources.jar: com/hummer/im/chatroom/_internals/rpc/RPCChangeChatRoomRole.java <==
package com.hummer.im.chatroom._internals.rpc;

import android.support.annotation.NonNull;

import com.hummer.im.Error;
import com.hummer.im.HMR;
import com.hummer.im._internals.HMRContext;
import com.hummer.im.chatroom._internals.packet.Marshallable;
import com.hummer.im.chatroom._internals.packet.Uint32;
import com.hummer.im.chatroom._internals.packet.Uint64;
import com.hummer.im.chatroom._internals.proto.ChatRoomProto;
import com.hummer.im.id.ChatRoom;
import com.hummer.im.shared.completion.CompletionArg;
import com.hummer.im.shared.completion.CompletionUtils;


public class RPCChangeChatRoomRole extends
        ChatRoomRPC<ChatRoomProto.PCS_CommonOperatorAuth2Res> {

    public RPCChangeChatRoomRole(long roomid, long uid, ChatRoomProto.AdminRoleTypeEnum roler,
                                 ChatRoomProto.ChatRoomOpEnum op,
                                 CompletionArg<ChatRoom> completion) {
        this.roomid = roomid;
        this.uid = uid;
        this.op = op;
        this.roler = roler;
        this.mCompletion = completion;
    }

    @Override
    public String getFunctionName() {
        return "UpdateRoler";
    }

    @Override
    public String serviceName() {
        return "chatroom_auther";
    }

    @Override
    public Marshallable requestObj() {
        ChatRoomProto.PCS_UpdateChatRoomRolerReq req = new ChatRoomProto.PCS_UpdateChatRoomRolerReq();
        req.appkey = Uint32.toUInt(HMRContext.appId);
        req.roomid = Uint32.toUInt(roomid);
        req.admin = Uint64.toUInt(HMR.getMe().getId());
        req.uid = Uint64.toUInt(uid);
        req.op = Uint32.toUInt(op.ordinal());
        req.roler = roler.getCode();
        return req;
    }

    @Override
    public void handleSuccess(@NonNull ChatRoomProto.PCS_CommonOperatorAuth2Res res)
            throws Throwable {
        CompletionUtils.dispatchSuccess(mCompletion, new ChatRoom(res.roomId.longValue()));
    }

    @Override
    public void handleError(@NonNull Error err) {
        CompletionUtils.dispatchFailure(mCompletion, err);
    }

    private final CompletionArg<ChatRoom> mCompletion;

    private final long roomid;
    private final long uid;
    private final ChatRoomProto.ChatRoomOpEnum op;
    private final ChatRoomProto.AdminRoleTypeEnum roler;
}

==> chatroom-2.6.101-sources.jar: com/hummer/im/chatroom/_internals/rpc/RPCChangeChatRoomRole.java <==
package com.hummer.im.chatroom._internals.rpc;

import android.support.annotation.NonNull;

import com.hummer.im.Error;
import com.hummer.im.HMR;
import com.hummer.im._internals.HMRContext;
import com.hummer.im.chatroom._internals.packet.Marshallable;
import com.hummer.im.chatroom._internals.packet.Uint32;
import com.hummer.im.chatroom._internals.packet.Uint64;
import com.hummer.im.chatroom._internals.proto.ChatRoomProto;
import com.hummer.im.model.completion.RichCompletion;
import com.hummer.im.model.completion.CompletionUtils;


public class RPCChangeChatRoomRole extends
        ChatRoomRPC<ChatRoomProto.PCS_CommonOperatorAuth2Res> {

    public RPCChangeChatRoomRole(long roomid, long uid, ChatRoomProto.AdminRoleTypeEnum roler,
                                 ChatRoomProto.ChatRoomOpEnum op,
                                 RichCompletion completion) {
        this.roomid = roomid;
        this.uid = uid;
        this.op = op;
        this.roler = roler;
        this.mCompletion = completion;
    }

    @Override
    public String getFunctionName() {
        return "UpdateRoler";
    }

    @Override
    public String serviceName() {
        return "chatroom_auther";
    }

    @Override
    public Marshallable requestObj() {
        ChatRoomProto.PCS_UpdateChatRoomRolerReq req = new ChatRoomProto.PCS_UpdateChatRoomRolerReq();
        req.appkey = Uint32.toUInt(HMRContext.appId);
        req.roomid = Uint32.toUInt(roomid);
        req.admin = Uint64.toUInt(HMR.getMe().getId());
        req.uid = Uint64.toUInt(uid);
        req.op = Uint32.toUInt(op.ordinal());
        req.roler = roler.getCode();
        return req;
    }

    @Override
    public void handleSuccess(@NonNull ChatRoomProto.PCS_CommonOperatorAuth2Res res) {
        CompletionUtils.dispatchSuccess(mCompletion);
    }

    @Override
    public void handleError(@NonNull Error err) {
        CompletionUtils.dispatchFailure(mCompletion, err);
    }

    private final RichCompletion mCompletion;

    private final long roomid;
    private final long uid;
    private final ChatRoomProto.ChatRoomOpEnum op;
    private final ChatRoomProto.AdminRoleTypeEnum roler;
}
